@@ -3,8 +3,9 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
 	auxlut=NULL, prednames=NULL, strvar=NULL, predfac=NULL, makedummy=FALSE,
 	nonresp=FALSE, RHGlut=NULL, getwt=FALSE, getwtvar=NULL,
 	strwtvar='strwt', P2POINTCNT=NULL, npixelvar=NULL, stratcombine=FALSE,
-	minplotnum.unit=10, unit.action="keep", minplotnum.strat=2, na.rm=TRUE,
- 	removeifnostrata=FALSE, auxtext="auxlut", removetext="unitarea",
+	minplotnum.unit=10, unit.action="keep", unitlevels=NULL, 
+	minplotnum.strat=2, na.rm=TRUE, removeifnostrata=FALSE, 
+ 	auxtext="auxlut", removetext="unitarea",
 	pvars2keep=NULL, standardize=TRUE, AOI=FALSE){
 
   ##################################################################################
@@ -58,7 +59,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
 	  unitarea <- unitarea[unitarea[[unitvar]] %in% auxlut[[unitvar]], ]
 	}
   }
- 
+
   #######################################################################
   ## Check strata
   #######################################################################
@@ -74,6 +75,11 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     if (length(grep("Total", lastrow, ignore.case=TRUE)) > 0) {
       auxlut <- auxlut[-nrow(auxlut)]
     }
+	
+	## Make strvar a factor for retaining order for collapsing
+	if (!is.factor(auxlut[[strvar]])) {
+	  auxlut[[strvar]] <- factor(auxlut[[strvar]])
+	}
  
     ## If auxlut is NULL, generate based on unitvars in pltx
     #############################################################
@@ -106,7 +112,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
 				by=c(unitvars, strvars), .SDcols=sumvars]
       setnames(auxlut, c(unitvars, strvars, sumvars))
     }
-    setkeyv(auxlut, unitvars)
+    #setkeyv(auxlut, unitvars)
     strunitvars <- c(unitvars, strvars)
 
     ## Check if class of unitvar in auxlut matches class of unitvar in pltx
@@ -241,7 +247,38 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
       auxlut$npixels <- NULL
     }
   }
+  
+  ## Get order of unitvar for collapsing
+  if (!is.null(unitlevels) && !is.factor(auxlut[[unitvar]])) {
+    auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels = unitlevels)
+	setorderv(auxlut, c(unitvar, unitvar2))
+  }
  
+  ##################################################################################
+  ## If more than one unitvar, concatenate into 1 unitvar
+  ##################################################################################
+  if (length(unitvars) > 1) {
+    unitvar21 <- paste(unitvar2, unitvar, sep="-")
+    auxlut[[unitvar21]] <- paste(auxlut[[unitvar2]], auxlut[[unitvar]], sep="-")
+    #auxlut[, c(unitvar, unitvar2) := NULL]
+
+    pltx[[unitvar21]] <- paste(pltx[[unitvar2]], pltx[[unitvar]], sep="-")
+    if (!is.null(unitarea)) {
+      unitarea[[unitvar21]] <- paste(unitarea[[unitvar2]], unitarea[[unitvar]], sep="-")
+      unitarea[, c(unitvar, unitvar2) := NULL]
+    }
+  
+    if (!is.null(RHGlut)) {
+      RHGlut[[unitvar21]] <- paste(RHGlut[[unitvar2]], RHGlut[[unitvar]], sep="-")
+      RHGlut[, c(unitvar, unitvar2) := NULL]
+    }
+	
+    unitvar <- unitvar21
+	unitlevels <- unique(auxlut[[unitvar]])
+	auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels = unitlevels)
+    pltx[[unitvar]] <- factor(pltx[[unitvar]], levels=unitlevels)
+  }
+  
   ## Merge P2POINTCNT to auxlut
   ##################################################
   if (!is.null(P2POINTCNT) && !"P2POINTCNT" %in% names(auxlut)) {
@@ -257,29 +294,18 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     auxlut[is.na(auxlut)] <- 0
   }
 
-  ##################################################################################
-  ## If more than one unitvar, concatenate into 1 unitvar
-  ##################################################################################
-  if (length(unitvars) > 1) {
-    unitvar12 <- paste(unitvar2, unitvar, sep="-")
-    auxlut[[unitvar12]] <- paste(auxlut[[unitvar2]], auxlut[[unitvar]], sep="-")
-    #auxlut[, c(unitvar, unitvar2) := NULL]
+  ## Redefine strunitvars
+  strunitvars <- c(unitvar, strvar)
 
-    pltx[[unitvar12]] <- paste(pltx[[unitvar2]], pltx[[unitvar]], sep="-")
-    if (!is.null(unitarea)) {
-      unitarea[[unitvar12]] <- paste(unitarea[[unitvar2]], unitarea[[unitvar]], sep="-")
-      unitarea[, c(unitvar, unitvar2) := NULL]
-    }
-  
-    if (!is.null(RHGlut)) {
-      RHGlut[[unitvar12]] <- paste(RHGlut[[unitvar2]], RHGlut[[unitvar]], sep="-")
-      RHGlut[, c(unitvar, unitvar2) := NULL]
-    }
- 
-    strunitvars <- unique(replace(strunitvars, which(strunitvars %in% c(unitvar, unitvar2)), unitvar12))
-    unitvar <- unitvar12
+  ## Make unitvar a factor for retaining order for collapsing{
+  if (!is.factor(auxlut[[unitvar]])) {
+    if (is.null(unitlevels)) {
+	  unitlevels <- unique(auxlut[[unitvar]])
+	}
+    auxlut[[unitvar]] <- factor(auxlut[[unitvar]], levels=unitlevels)
+    pltx[[unitvar]] <- factor(pltx[[unitvar]], levels=unitlevels)
   }
- 
+
   ###################################################################################
   ## Check number of plots by unitvar
   ##	 (including partially sampled plots - COND_STATUS_CD=5)
@@ -297,6 +323,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     warning("minplotnum.unit should be at least 2")
     #minplotnum.unit <- 2
   }
+
   if (strata) {
     if (minplotnum.strat > minplotnum.unit) {
       minplotnum.strat <- minplotnum.unit
@@ -311,19 +338,26 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   auxlut <- pltcnts$unitlut
   errtab <- pltcnts$errtab
   nostrat <- pltcnts$nostrat
- 
+
   ## If unit.action="remove", remove estimation with less than minplotnum.unit plots
   if (any(auxlut$n.total < minplotnum.unit)) {
-    unitlessthan <- auxlut[auxlut$n.total < minplotnum.unit][[unitvar]]
-    if (length(unitlessthan) > 0) {
+    unitltmin <- unique(errtab[[unitvar]][errtab$n.total < minplotnum.unit])
+
+    if (length(unitltmin) > 0) {
       if (unit.action == "remove") {
         message("removing domains with plots less than ", minplotnum.unit,
-		": ", toString(unitlessthan))
-        auxlut <- auxlut[!auxlut[[unitvar]] %in% unitlessthan, ]
-        pltx <- pltx[!pltx[[unitvar]] %in% unitlessthan, ]
-        unitarea <- unitarea[!unitarea[[unitvar]] %in% unitlessthan, ]
-        errtab <- errtab[!errtab[[unitvar]] %in% unitlessthan, ]
+		": ", toString(unitltmin))
+        auxlut <- auxlut[!auxlut[[unitvar]] %in% unitltmin, ]
+        pltx <- pltx[!pltx[[unitvar]] %in% unitltmin, ]
+        unitarea <- unitarea[!unitarea[[unitvar]] %in% unitltmin, ]
+        errtab <- errtab[!errtab[[unitvar]] %in% unitltmin, ]
       } else if (unit.action == "keep") {
+        message("there are ", length(unitltmin), " units with less than minplotnum.unit (", 
+		   minplotnum.unit, ") plots:\n", 
+		   toString(unitltmin)) 
+        message("if want to combine units that are less than minplotnum.unit, ",
+		        "set unit.action='combine' in unit.opts parameter... ",
+				"\ncheck returned object, stratwarnlut\n")		   
         minplotnum.unit <- 0
         #errtab <- errtab[, errtyp := "none"]
       }
@@ -335,7 +369,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     pltx <- pltx[pltx[[strvar]] %in% unique(auxlut[[strvar]]),]
     message("removing plots with invalid strata assignments")
   }
- 
+
   ###################################################################################
   ## Collapse strata and/or estimation unit classes if errtab warnings
   ###################################################################################
@@ -349,11 +383,6 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
       minplotnum.strat <- minplotnum.unit
     }
     unitcombine <- ifelse(unit.action == 'combine', TRUE, FALSE)
-    if (!unitcombine && any(errtab$n.total < minplotnum.unit)) {
-      stop("there are units with less than minplotnum.unit (", 
-		minplotnum.unit, ") plots:\n", 
-		toString(errtab[[unitvar]][errtab$n.total <- minplotnum.unit]))      
-    }
     collapse <- strat.collapse(stratacnt=auxlut, 
                                pltstratx=pltx, 
                                minplotnum.unit=minplotnum.unit, 
@@ -362,7 +391,15 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
                                unitvar=unitvar, strvar=strvar, 
                                stratcombine=stratcombine, 
                                unitcombine=unitcombine, 
-                               vars2combine=vars2combine)
+                               vars2combine=vars2combine)						 
+
+    if ((stratcombine || unitcombine) && !is.null(collapse$unitstrgrplut)) {
+	  message("check strata groups in returned object, unitstrgrplut\n")
+      unitstrgrplut <- collapse$unitstrgrplut
+	  unitstrgrplut <- merge(errtab, unitstrgrplut, by=strunitvars)
+    }
+
+    ## Get new variable definitions
     auxlut <- collapse$strlut
     unitvar <- collapse$unitvar
     strvar <- collapse$strvar
@@ -371,12 +408,14 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
  
     if (unitvar == "unitnew") {
       unitvars <- unitvar
-    }
+    } else {
+	  ## If more than one unitvar, 
+      ## split the concatenated unitvar variable to keep original columns
+      if (!is.null(unitvar2)) {
+        auxlut[, (unitvars) := tstrsplit(get(unitvar), "-", fixed=TRUE)]
+      }
+	}
     strunitvars <- c(unitvar, strvar)
-
-    if (stratcombine || unitcombine) {
-      unitstrgrplut <- collapse$unitstrgrplut
-    }
   }
 
   ###################################################################################
@@ -470,7 +509,7 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     } else {
       ## Check for strwt
       if (!strwtvar %in% names(auxlut)) {
-        stop(strwtvar, " not in stratalut... include getwtvar and getwt=TRUE")
+        stop(strwtvar, " not in stratalut... include getwtvar and getwt=TRUE in strata_opts parameter")
       }
       ## Check to see if sum(strwt) = 1
       test <- auxlut[, round(sum(get(strwtvar), na.rm=TRUE)), by=unitvar]
@@ -493,12 +532,12 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
   setkeyv(pltx, puniqueid)
 
   ## Set column order
-  if (length(unitvars) > 1) {
-    setcolorder(auxlut, c(unitvars, strunitvars, 
-			names(auxlut)[!names(auxlut) %in% c(unitvars, strunitvars)]))
-  } else {
+  #if (length(unitvars) > 1) {
+  #  setcolorder(auxlut, c(unitvars, strunitvars, 
+  #			names(auxlut)[!names(auxlut) %in% c(unitvars, strunitvars)]))
+  #} else {
     setcolorder(auxlut, c(strunitvars, names(auxlut)[!names(auxlut) %in% strunitvars]))
-  }
+  #}
 
   returnlst <- list(pltx=as.data.table(pltx),
 		auxlut=as.data.table(auxlut),
@@ -550,7 +589,9 @@ check.auxiliary <- function(pltx, puniqueid, module="GB", strata=FALSE,
     }
     if (!is.null(unitstrgrplut)) {
       returnlst$stratcombinelut <- unitstrgrplut
-    }
+    } else if (!is.null(errtab)) {
+	  returnlst$stratwarnlut <- errtab
+	}
   }
 
   return(returnlst)
