@@ -459,10 +459,10 @@ modGBtree <- function(GBpopdat,
   estdat <- check.estdata(esttype=esttype, pop_fmt=pop_fmt, pop_dsn=pop_dsn,
                 pltcondf=pltcondx, cuniqueid=cuniqueid, condid=condid, 
                 treex=treex, seedx=seedx, estseed=estseed, woodland=woodland,
-				sumunits=sumunits, landarea=landarea, ACI.filter=ACI.filter, 
-				pcfilter=pcfilter, allin1=allin1, 
-				estround=estround, pseround=pseround, divideby=divideby, 
-                addtitle=addtitle, returntitle=returntitle, 
+				sumunits=sumunits, totals=totals, landarea=landarea, 
+				ACI.filter=ACI.filter, pcfilter=pcfilter, 
+				allin1=allin1, estround=estround, pseround=pseround, 
+				divideby=divideby, addtitle=addtitle, returntitle=returntitle, 
                 rawdata=rawdata, rawonly=rawonly, savedata=savedata, 
                 outfolder=outfolder, overwrite_dsn=overwrite_dsn,
                 overwrite_layer=overwrite_layer, outfn.pre=outfn.pre, 
@@ -477,6 +477,7 @@ modGBtree <- function(GBpopdat,
   estseed <- estdat$estseed
   woodland <- estdat$woodland
   sumunits <- estdat$sumunits
+  totals <- estdat$totals
   landarea <- estdat$landarea
   allin1 <- estdat$allin1
   estround <- estdat$estround
@@ -501,11 +502,11 @@ modGBtree <- function(GBpopdat,
   if ("INVYR" %in% names(pltcondf)) {
     invyr <- sort(unique(pltcondf$INVYR))
   }
- 
+
   #############################################################################
   ### Check row and column data
   #############################################################################
-  rowcolinfo <- check.rowcol(gui=gui, esttype=esttype, conn=conn,
+  rowcolinfo <- check.rowcol(gui=gui, esttype=esttype,
                      treef=treef, seedf=seedf,
                      condf=pltcondf, cuniqueid=cuniqueid,
                      tuniqueid=tuniqueid, estseed=estseed,
@@ -516,7 +517,8 @@ modGBtree <- function(GBpopdat,
                      title.rowvar=title.rowvar, title.colvar=title.colvar,
                      rowlut=rowlut, collut=collut, rowgrp=rowgrp,
                      rowgrpnm=rowgrpnm, rowgrpord=rowgrpord,
-                     landarea=landarea, states=states)
+                     landarea=landarea, states=states, 
+					 cvars2keep="COND_STATUS_CD")
   treef <- rowcolinfo$treef
   seedf <- rowcolinfo$seedf
   condf <- rowcolinfo$condf
@@ -525,6 +527,8 @@ modGBtree <- function(GBpopdat,
   domainlst <- rowcolinfo$domainlst
   rowvar <- rowcolinfo$rowvar
   colvar <- rowcolinfo$colvar
+  rowvarnm <- rowcolinfo$rowvarnm
+  colvarnm <- rowcolinfo$colvarnm
   row.orderby <- rowcolinfo$row.orderby
   col.orderby <- rowcolinfo$col.orderby
   row.add0 <- rowcolinfo$row.add0
@@ -537,14 +541,8 @@ modGBtree <- function(GBpopdat,
   tdomvar <- rowcolinfo$tdomvar
   tdomvar2 <- rowcolinfo$tdomvar2
   grpvar <- rowcolinfo$grpvar
-  #rm(rowcolinfo)
+  rm(rowcolinfo)
 
-  ## Generate a uniquecol for estimation units
-  if (!sumunits && colvar == "NONE") {
-    uniquecol <- data.table(unitarea[[unitvar]])
-    setnames(uniquecol, unitvar)
-    uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
-  }
 
   ###############################################################################
   ### Get estimation data from tree table
@@ -559,45 +557,40 @@ modGBtree <- function(GBpopdat,
   if (is.null(treedat)) return(NULL) 
   tdomdat <- treedat$tdomdat
 
-  if (rowvar != "TOTAL") {
-    #if (!row.add0) {
-      if (any(is.na(tdomdat[[rowvar]]))) {
-	    if (!row.FIAname) {
-		  rval <- ifelse (any(!is.na(tdomdat[[rowvar]]) & tdomdat[[rowvar]] == 0), max(tdomdat[[rowvar]], na.rm=TRUE), 0)
-		  tdomdat[is.na(tdomdat[[rowvar]]), rowvar] <- rval
-		  levels(uniquerow[[rowvar]]) <- c(levels(uniquerow[[rowvar]]), as.character(rval))
-		  uniquerow[is.na(uniquerow[[rowvar]]), rowvar] <- as.character(rval)
-        } else {
-          tdomdat <- tdomdat[!is.na(tdomdat[[rowvar]]), ]
-        }
-	   }
-    #}
-    if (colvar != "NONE") {
-      #if (!col.add0) {
-        if (any(is.na(tdomdat[[colvar]]))) {
-	      if (!col.FIAname) {
-		    cval <- ifelse (any(!is.na(tdomdat[[colvar]]) & tdomdat[[colvar]] == 0), max(tdomdat[[colvar]], na.rm=TRUE), 0)
-		    tdomdat[is.na(tdomdat[[colvar]]), colvar] <- cval
-			levels(uniquecol[[colvar]]) <- c(levels(uniquecol[[colvar]]), as.character(cval))
-			uniquecol[is.na(uniquecol[[colvar]]), colvar] <- as.character(cval)
-		  } else {
-            tdomdat <- tdomdat[!is.na(tdomdat[[colvar]]), ]
-          }
-		}
-      #}
-    }
-  } 
   ## Merge tdomdat with condx
   xchk <- check.matchclass(condx, tdomdat, c(cuniqueid, condid))
   condx <- xchk$tab1
   tdomdat <- xchk$tab2
   tdomdat <- merge(condx, tdomdat, by=c(cuniqueid, condid))
-
+  
   estvar <- treedat$estvar
   estvar.name <- treedat$estvar.name
   estvar.filter <- treedat$estvar.filter
   tdomvarlst <- treedat$tdomvarlst
   estunits <- treedat$estunits
+  
+  ## Check for matching levels in x and xunique
+  if (!is.null(uniquerow)) {
+    chklevels <- checklevels(x = tdomdat, 
+	                         uniquex = uniquerow,
+							 xvar = rowvar) 
+	tdomdat <- chklevels$x
+    uniquerow <- chklevels$uniquex	
+  }
+  if (!is.null(uniquecol)) {
+    chklevels <- checklevels(x = tdomdat, 
+	                         uniquex = uniquecol,
+							 xvar = colvar) 
+	tdomdat <- chklevels$x
+    uniquecol <- chklevels$uniquex	
+  }
+ 
+  ## Generate a uniquecol for estimation units
+  if (!sumunits && colvar == "NONE") {
+    uniquecol <- data.table(unitarea[[unitvar]])
+    setnames(uniquecol, unitvar)
+    uniquecol[[unitvar]] <- factor(uniquecol[[unitvar]])
+  }
  
   ###############################################################################
   ### Get titles for output tables
@@ -664,7 +657,6 @@ modGBtree <- function(GBpopdat,
   if (rowvar != "TOTAL") {
     tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		    by=c(strunitvars, cuniqueid, rowvar), .SDcols=estvar.name]
-    tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[rowvar]]),]
     unit_rowest <- GBest.pbar(sumyn = estvar.name, 
                               ysum = tdomdatsum,
                               uniqueid = cuniqueid, 
@@ -676,7 +668,6 @@ modGBtree <- function(GBpopdat,
     if (colvar != "NONE") {
       tdomdatsum <- tdomdat[, lapply(.SD, sum, na.rm=TRUE), 
 		      by=c(strunitvars, cuniqueid, colvar), .SDcols=estvar.name]
-      tdomdatsum <- tdomdatsum[!is.na(tdomdatsum[[colvar]]),]
       unit_colest <- GBest.pbar(sumyn = estvar.name, 
                                 ysum = tdomdatsum,
                                 uniqueid = cuniqueid, 
@@ -852,17 +843,22 @@ modGBtree <- function(GBpopdat,
   message("getting output...")
   estnm <- "est"
   tabs <- est.outtabs(esttype=esttype, sumunits=sumunits, areavar=areavar, 
-	      unitvar=unitvar, unitvars=unitvars, unit_totest=unit_totest, 
-	      unit_rowest=unit_rowest, unit_colest=unit_colest, unit_grpest=unit_grpest, 
-	      rowvar=rowvar, colvar=colvar, uniquerow=uniquerow, uniquecol=uniquecol, 
-	      rowgrp=rowgrp, rowgrpnm=rowgrpnm, rowunit=rowunit, totunit=totunit, 
-	      allin1=allin1, savedata=savedata, addtitle=addtitle, title.ref=title.ref, 
-	      title.colvar=title.colvar, title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
-	      title.unitvar=title.unitvar, title.estpse=title.estpse, title.est=title.est, 
-	      title.pse=title.pse, rawdata=rawdata, rawonly=rawonly, outfn.estpse=outfn.estpse, 
-	      outfolder=outfolder, outfn.date=outfn.date, overwrite=overwrite_layer, 
-	      estnm=estnm, estround=estround, pseround=pseround, divideby=divideby, 
-	      returntitle=returntitle, estnull=estnull, psenull=psenull, raw.keep0=raw.keep0) 
+	        unitvar=unitvar, unitvars=unitvars, unit_totest=unit_totest, 
+	        unit_rowest=unit_rowest, unit_colest=unit_colest, unit_grpest=unit_grpest, 
+	        rowvar=rowvarnm, colvar=colvarnm, uniquerow=uniquerow, uniquecol=uniquecol, 
+	        rowgrp=rowgrp, rowgrpnm=rowgrpnm, rowunit=rowunit, totunit=totunit, 
+	        allin1=allin1, savedata=savedata, addtitle=addtitle, 
+			title.ref=title.ref, title.colvar=title.colvar, 
+			title.rowvar=title.rowvar, title.rowgrp=title.rowgrp, 
+	        title.unitvar=title.unitvar, title.estpse=title.estpse, 
+			title.est=title.est, title.pse=title.pse, 
+			rawdata=rawdata, rawonly=rawonly, outfn.estpse=outfn.estpse, 
+	        outfolder=outfolder, outfn.date=outfn.date, 
+			overwrite=overwrite_layer, estnm=estnm, 
+			estround=estround, pseround=pseround, divideby=divideby, 
+	        returntitle=returntitle, estnull=estnull, psenull=psenull, 
+			raw.keep0=raw.keep0) 
+			
   est2return <- tabs$tabest
   pse2return <- tabs$tabpse
 
@@ -875,8 +871,21 @@ modGBtree <- function(GBpopdat,
   if(returntitle) {
     returnlst$titlelst <- alltitlelst
   }
- 
+
   if (rawdata) {
+    ## Add total number of plots in population to unit_totest and totest (if sumunits=TRUE)
+    UNITStot <- sort(unique(unit_totest[[unitvar]]))
+    NBRPLTtot <- stratalut[stratalut[[unitvar]] %in% UNITStot, list(NBRPLT = sum(n.strata, na.rm=TRUE)), 
+	                 by=unitvars]
+
+	#setnames(NBRPLTtot, "V1", "NBRPLT")
+	if ("unit_totest" %in% names(tabs$rawdat)) {
+	  tabs$rawdat$unit_totest <- merge(tabs$rawdat$unit_totest, NBRPLTtot, by=unitvars)
+	}
+	if (sumunits && "totest" %in% names(tabs$rawdat)) {
+	  tabs$rawdat$totest <- data.frame(tabs$rawdat$totest, NBRPLT = sum(NBRPLTtot$NBRPLT))
+	}
+
     rawdat <- tabs$rawdat
     rawdat$domdat <- setDF(tdomdat) 
     rawdat$estvar <- estvar.name
